/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   CaQaBase.h
/// \date   01.03.2024
/// \brief  Base class for tracking QA (source)
/// \author Sergei Zharko <s.zharko@gsi.de>

#include "CaQaBase.h"

using cbm::algo::ca::QaBase;

// ---------------------------------------------------------------------------------------------------------------------
//
bool QaBase::CheckInit() const
{
  bool res = true;
  if (!fpParameters) {
    L_(error) << "cbm::algo::ca::OutputQa::Build(): parameters object is undefined";
    res = false;
  }
  if (!fpInputData) {
    L_(error) << "cbm::algo::ca::OutputQa::Build(): input data object is undefined";
    res = false;
  }
  if (!fpvTracks) {
    L_(error) << "cbm::algo::ca::OutputQa::Build(): track vector is undefined";
    res = false;
  }
  if (!fpvRecoHits) {
    L_(error) << "cbm::algo::ca::OutputQa::Build(): used hit index vector is undefined";
    res = false;
  }
  return res;
}
