/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// @file   KfSetup.cxx
/// @brief  Setup representation for the Kalman-filter framework (source)
/// @since  28.03.2024
/// @author Sergei Zharko <s.zharko@gsi.de>

#include "KfSetup.h"

#include <sstream>

using cbm::algo::kf::Setup;

// ---------------------------------------------------------------------------------------------------------------------
//
template<typename DataT>
void Setup<DataT>::CheckConsistency() const
{
  std::stringstream errMsg;

  // checks go here... the errMsg is to be filled on each checking stage

  if (!errMsg.str().empty()) {
    throw std::runtime_error(errMsg.str());
  }
}

// ---------------------------------------------------------------------------------------------------------------------
//
template<typename DataT>
void Setup<DataT>::Init()
{
  fbInitialized = true;
  CheckConsistency();
}

// ---------------------------------------------------------------------------------------------------------------------
//
template<typename DataT>
std::string Setup<DataT>::ToString(int verbosity, int indentLevel) const
{
  std::stringstream msg;

  if (verbosity > 0) {
    constexpr char indentCh = '\t';
    std::string indent(indentLevel, indentCh);
    msg << indent << " ----- KF setup -----\n";
    msg << indent << "MATERIAL LAYERS:\n";
    for (const auto& layer : fvMatLayers) {
      msg << indent << indentCh << layer.ToString() << '\n';
    }
  }

  return msg.str();
}

template class cbm::algo::kf::Setup<float>;
template class cbm::algo::kf::Setup<double>;
//template class cbm::algo::kf::Setup<fvec>;
